package org.jayasoft.ivyde.eclipse.ui.preferences;

import java.io.File;
import java.net.MalformedURLException;

import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.jface.preference.FileFieldEditor;
import org.eclipse.jface.preference.StringFieldEditor;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;
import org.jayasoft.ivyde.eclipse.IvyPlugin;


/**
 * This class represents a preference page that
 * is contributed to the Preferences dialog. By 
 * subclassing <samp>FieldEditorPreferencePage</samp>, we
 * can use the field support built into JFace that allows
 * us to create a page that is small and knows how to 
 * save, restore and apply itself.
 * <p>
 * This page is used to modify preferences only. They
 * are stored in the preference store that belongs to
 * the main plug-in class. That way, preferences can
 * be accessed directly via the preference store.
 */

public class IvyPreferencePage
	extends FieldEditorPreferencePage
	implements IWorkbenchPreferencePage {

	public IvyPreferencePage() {
		super(GRID);
		setPreferenceStore(IvyPlugin.getDefault().getPreferenceStore());
		setDescription("Ivy plugin preference page.");
	}
	
	/**
	 * Creates the field editors. Field editors are abstractions of
	 * the common GUI blocks needed to manipulate various types
	 * of preferences. Each field editor knows how to save and
	 * restore itself.
	 */
	public void createFieldEditors() {
		addField(new FileFieldEditor(PreferenceConstants.IVYCONF_PATH, "&IvyConf URL:", getFieldEditorParent()) {
            /* (non-Javadoc)
             * Method declared on StringButtonFieldEditor.
             * Opens the file chooser dialog and returns the selected file as an url.
             */
            protected String changePressed() {
                String f = super.changePressed();
                if (f == null) {
                    return null;
                } else {
                    File d = new File(f);

                    try {
                        return d.toURL().toExternalForm();
                    } catch (MalformedURLException e) {
                        return null;
                    }
                }
            }
            
            protected boolean checkState() {
                return true;
            }
        });
        addField(new StringFieldEditor(PreferenceConstants.ORGANISATION, "&Organisation:", getFieldEditorParent()));
        addField(new StringFieldEditor(PreferenceConstants.ORGANISATION_URL, "Organisation &URL:", getFieldEditorParent()));
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
	 */
	public void init(IWorkbench workbench) {
	}
	
}